/* ###
 * IP: GHIDRA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package docking.options.editor;

import java.beans.PropertyEditor;

/**
 * A {@link PropertyEditor} that allows the user to edit strings by way of a File editor, as is
 * done by {@link StringBasedFileEditor}.  In other words, the user can use the file chooser to
 * pick a file.  That file is then turned into a String. 
 * 
 * <P>This class has the restriction that it will only 
 * take in {@link String} objects and will only give out {@link String} objects.
 */
public class StringBasedFileEditor extends FileChooserEditor {

	@Override
	public void setValue(Object value) {
		if (!(value instanceof String)) {
			throw new IllegalArgumentException("Editor only edits String objects!");
		}

		super.setValue(value);
	}

	@Override
	public Object getValue() {
		return getAsText();
	}
}
